package com.practice.migration.nov_21_23.custom;

import lombok.Data;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Getter
@Setter
@Data
@ToString
public class FTLConverter {
    private String tagName;
    private String id;
    private String className;
    private List<FTLConverter> children;
    private Set<String> attributes;

    public static void main(String[] args) {
        String htmlString = "[#macro smartBundlingOneLine utilityNeed]\n" +
                "    <div class=\"smart-bundling-one-line\" id=\"smartBundlingOneLine-${utilityNeed.mainSku}\">\n" +
                "        <div class=\"smart-bundling-cart-icon\">\n" +
                "            <img src=\"[@wsgc.docurl url='images/checkout/svg/cartDesktop.svg'/]\"/>\n" +
                "        </div>\n" +
                "        [#if utilityNeed.data.copy??]\n" +
                "            <div class=\"smart-bundling-copy\">${utilityNeed.data.copy}</div>\n" +
                "        [/#if]\n" +
                "        [#if smartBundlingCartConfiguration.isDesktopDismissProductRecommendationEnabledCartPage()]\n" +
                "            <div class=\"smart-bundling-close\">\n" +
                "                <a><img src=\"[@wsgc.docurl url='images/svg/close.svg'/]\" class=\"smartBundlingClose\"/></a>\n" +
                "            </div>\n" +
                "        [/#if]\n" +
                "    </div>\n" +
                "[/#macro]";
        System.out.println("Final O/P"+ parseHTML(htmlString));
    }


    public FTLConverter(String tagName, String id, String className) {
        this.tagName = tagName;
        this.id = id;
        this.className = className;
        this.children = new ArrayList<>();
        this.attributes = new HashSet<>();
    }

    public void addChild(FTLConverter child) {
        this.children.add(child);
    }

    public static FTLConverter parseHTML(String htmlString) {
        Pattern tagPattern = Pattern.compile("<(\\w+)(.*?)>(.*?)</\\1>", Pattern.DOTALL);
        Matcher matcher = tagPattern.matcher(htmlString);

        if (matcher.find()) {
            String tagName = matcher.group(1);
            String attributes = matcher.group(2);
            String innerContent = matcher.group(3);

            String id = extractAttribute(attributes, "id");
            String className = extractAttribute(attributes, "class");

            FTLConverter element = new FTLConverter(tagName, id, className);

            // Recursively parse children
            FTLConverter child = parseHTML(innerContent);
            if (child != null) {
                element.addChild(child);
            }

            return element;
        }

        return null;
    }

    private static String extractAttribute(String attributes, String attributeName) {
        Pattern attributePattern = Pattern.compile(attributeName + "=\"(.*?)\"");
        Matcher matcher = attributePattern.matcher(attributes);

        if (matcher.find()) {
            return matcher.group(1);
        }
        return null;
    }

    // Getters, setters, and other methods omitted for brevity
}

