[#import '/macros/widgets.ftl' as widgets/]
[#import '/macros/config.ftl' as config/]
[#import '/components/common/_abtest-assignment.ftl' as abTest/]
[#import '/macros/productImage.ftl' as productImage/]
[#import '/macros/pricedisplay.ftl' as priceDisplay/]
[#import '/macros/model.ftl' as model/]

[#--
    Determines if Smart Bundling is currently enabled for the Desktop RAC.
    If so, UtilityNeeds information should be displayed there.

    @return true if Smart Bundling is enabled for the Desktop RAC, otherwise false
--]
[#function isDesktopEnabled]
    [#if isSmartBundlingDesktopEnabledRac??]
        [#return isSmartBundlingDesktopEnabledRac /]
    [/#if]

    [#assign isSmartBundlingDesktopEnabledRac = false /]

    [#if smartBundlingRacConfiguration?? && smartBundlingRacConfiguration.isDesktopEnabledRac()]
        [#if smartBundlingRacConfiguration.isAbTestDesktopEnabledRac()]
            [#local variationId = smartBundlingRacConfiguration.getDesktopAbTestVariationIdRac() /]
            [#local variationAssignment = abTest.getAbTestVariationAssignment(smartBundlingRacConfiguration.getDesktopAbTestIdRac()) /]

            [#assign isSmartBundlingDesktopEnabledRac = variationAssignment == variationId  /]
        [#else]
            [#assign isSmartBundlingDesktopEnabledRac = true /]
        [/#if]
    [/#if]
    [#return isSmartBundlingDesktopEnabledRac /]
[/#function]

[#function isDesktopCartEnabled]
    [#if isSmartBundlingDesktopEnabledCart??]
        [#return isSmartBundlingDesktopEnabledCart /]
    [/#if]

    [#assign isSmartBundlingDesktopEnabledCart = false /]

    [#if smartBundlingCartConfiguration?? && smartBundlingCartConfiguration.isDesktopEnabledCartPage()]
        [#if smartBundlingCartConfiguration.isAbTestDesktopEnabledCartPage()]
            [#local variationId = smartBundlingCartConfiguration.getDesktopAbTestVariationIdCartPage() /]
            [#local variationAssignment = abTest.getAbTestVariationAssignment(smartBundlingCartConfiguration.getDesktopAbTestIdCartPage()) /]

            [#assign isSmartBundlingDesktopEnabledCart = variationAssignment == variationId  /]
        [#else]
            [#assign isSmartBundlingDesktopEnabledCart = true /]
        [/#if]
    [/#if]
    [#return isSmartBundlingDesktopEnabledCart /]
[/#function]

[#function shouldHideUtilitySkuCopy]
    [#if hideUtilitySkuCopy??]
        [#return hideUtilitySkuCopy /]
    [/#if]
    [#assign hideUtilitySkuCopy = false /]
    [#if smartBundlingCartConfiguration?? && smartBundlingCartConfiguration.isDesktopCopyHiddenEnabled()]
        [#if smartBundlingCartConfiguration.isAbTestDesktopCopyHiddenEnabled()]
            [#local variationAssignment = abTest.getAbTestVariationAssignment("smartBundlingCartCopy") /]
            [#if variationAssignment?? && variationAssignment == "showCopy"]
                [#assign hideUtilitySkuCopy = false]
                [#return hideUtilitySkuCopy]
            [/#if]
        [/#if]
        [#assign hideUtilitySkuCopy = true]
    [/#if]
    [#return hideUtilitySkuCopy]
[/#function]

[#macro richCartSmartBundlingItems]
    [#assign smartBundlingLinkSuffix = "&cm_src=smartbundlerac" /]
    [@widgets.jstemplate id="richCartSmartBundlingItemTemplate"]
        <div class="content-scroller-item">
            <div class="smart-bundling-item [%= isFirstElement %]">
                <div class="smart-bundling-copy">[%= copy %]</div>
                <div class="smart-bundling-content">
                    <div class="smart-bundling-image-container">
                        <a class="smart-bundling-link" href="/products/[%= groupId %]/?sku=[%= sku %]${smartBundlingLinkSuffix}">
                            [% if(productImageSrc) { %]
                            [#-- src is intentionally omitted as an attribute below as an empty src creates a second call to the PIP on construction --]
                            [#local imgSrc = "[%= productImageSrc %]"/]
                            <img src="${imgSrc}"  alt="[%= productImageAlt %]"/>
                            [% } %]
                        </a>
                    </div>
                    <div class="subset-pricing info">
                        <a class="smart-bundling-link" href="/products/[%= groupId %]/?sku=[%= sku %]${smartBundlingLinkSuffix}">
                            <h4 class="dynamic-text"  id="title">[%= title %]</h4>
                        </a>
                        <div class="product-price">
                            [% if(isSaleOrSpecial) { %]
                                [%= price %]
                            [% } %]
                            [% if(!isSaleOrSpecial) { %]
                                <span>Price:</span> [%= price %]
                            [% } %]
                        </div>
                        [%if(storeName !== "") { %]
                            <div class="bopis-store-info">
                                <span>Also Available in [%= storeName %] Store</span>
                            </div>
                        [% } %]
                        <div class="smart-bundling-add-to-cart" id="smart-bundling-atc-[%= sku %]">
                            <div class="subset-selection">
                                <div class="subset-qty quantity-selector">
                                    <input class="qty" id="rac_qty_[%= sku %]" aria-label="Quantity" type="number" inputmode="numeric"
                                           min="0" max="99" maxlength="2" placeholder="${config.quantityPlaceholder}"
                                           value="[%= itemQuantity %]"  autocomplete="none"
                                           data-addtocart="{&quot;sku&quot;:&quot;[%= sku %]&quot;,&quot;groupId&quot;:&quot;[%= groupId %]&quot;,&quot;catalog&quot;:&quot;[%= catalog %]&quot;,&quot;intlIneligibility&quot;:false[%if (pickupLocationCode !== undefined) { %],&quot;pickupLocationCode&quot;:&quot;[%= pickupLocationCode %]&quot;[% } %][%if (pickupServiceLevel !== undefined) { %],&quot;pickupServiceLevel&quot;:&quot;[%= pickupServiceLevel %]&quot;[% } %]}"/>
                                </div>
                            </div>
                            <div tabindex="0">
                                <button aria-label="Add to Cart" class="btn_addtobasket btn-add-to-cart btn-pip" sku="[%= sku %]">
                                    <span>Add to Cart</span>
                                </button>
                            </div>
                        </div>
                        <div class="smart-bundling-error">
                            <div class="general-error hidden"></div>
                            <div class="specific-error hidden"></div>
                        </div>
                    </div>
                </div>
                [% if(memberCopy) { %]
                    <div class="utility-member-copy">[%= memberCopy %]</div>
                [% } %]
            </div>
        </div>
    [/@widgets.jstemplate]
[/#macro]

[#macro cartSmartBundlingItems]
    [#assign smartBundlingLinkSuffix = "&cm_src=smartbundlecart" /]
    [@widgets.jstemplate id="cartSmartBundlingItemTemplate"]
        <div class="smart-bundling-content" id="smartBundlingContent-[%= mainSku %]-[%= sku %]">
            <div class="smart-bundling-image-container">
                <a class="smart-bundling-link" href="/products/[%= groupId %]/?sku=[%= sku %]${smartBundlingLinkSuffix}">
                    [% if(productImageSrc) { %]
                    [#local imgSrc = "[%= productImageSrc %]"/]
                    <img src="${imgSrc}"  alt="[%= productImageAlt %]"/>
                    [% } %]
                </a>
            </div>
            <div class="subset-pricing info">
                <a class="smart-bundling-link" href="/products/[%= groupId %]/?sku=[%= sku %]${smartBundlingLinkSuffix}">
                    <p class="smart-bundling-title">[%= title %]</p>
                </a>
                <div class="product-price">
                    [% if(isSaleOrSpecial) { %]
                        [%= price %]
                    [% } %]
                    [% if(!isSaleOrSpecial) { %]
                    <span>Price:</span> [%= price %]
                    [% } %]
                </div>
                <div class="smart-bundling-add-to-cart" id="smart-bundling-atc-[%= sku %]">
                    <div class="subset-selection">
                        <div class="subset-qty quantity-selector">
                            <input class="qty" id="rac_qty_[%= sku %]" aria-label="Quantity" type="number" inputmode="numeric"
                                   min="0" max="99" maxlength="2" placeholder="${config.quantityPlaceholder}"
                                   value="[%= itemQuantity %]"  autocomplete="none"
                                   data-addtocart="{&quot;sku&quot;:&quot;[%= sku %]&quot;,&quot;groupId&quot;:&quot;[%= groupId %]&quot;,&quot;catalog&quot;:&quot;[%= catalog %]&quot;,&quot;intlIneligibility&quot;:false[%if (pickupLocationCode !== undefined) { %],&quot;pickupLocationCode&quot;:&quot;[%= pickupLocationCode %]&quot;[% } %][%if (pickupServiceLevel !== undefined) { %],&quot;pickupServiceLevel&quot;:&quot;[%= pickupServiceLevel %]&quot;[% } %]}"/>
                        </div>
                    </div>
                    <div>
                        <button aria-label="Add to Cart" class="btn_addtobasket btn-add-to-cart btn-pip" sku="[%= sku %]">
                            <span>Add to Cart</span>
                        </button>
                    </div>
                </div>
                <div class="smart-bundling-error">
                    <div class="general-error hidden"></div>
                    <div class="specific-error hidden"></div>
                </div>
            </div>
        </div>
    [/@widgets.jstemplate]
[/#macro]

[#macro smartBundlingUtilityCopy mainSku="" memberCopy=""]
    [#if memberCopy?? && mainSku??]
        <div id="smartBundlingUtilityCopy-${mainSku}">
            <div class="smart-bundling-utility-member-copy"><p>${memberCopy}</p></div>
        </div>
    [/#if]
[/#macro]

[#macro smartBundlingOneLine utilityNeed]
    <div class="smart-bundling-one-line" id="smartBundlingOneLine-${utilityNeed.mainSku}">
        <div class="smart-bundling-cart-icon">
            <img src="[@wsgc.docurl url='images/checkout/svg/cartDesktop.svg'/]"/>
        </div>
        [#if utilityNeed.data.copy??]
            <div class="smart-bundling-copy">${utilityNeed.data.copy}</div>
        [/#if]
        [#if smartBundlingCartConfiguration.isDesktopDismissProductRecommendationEnabledCartPage()]
            <div class="smart-bundling-close">
                <a><img src="[@wsgc.docurl url='images/svg/close.svg'/]" class="smartBundlingClose"/></a>
            </div>
        [/#if]
    </div>
[/#macro]

[#macro cartLineItem utilityNeeds = [] mainSkuGroupId = ""]
    [#list utilityNeeds as utilityNeed]
        <div class="smart-bundling-container hidden" id="smartBundlingContainer-${utilityNeed.mainSku}">
            <div class="smart-bundling-atc-success smart-bundling-hidden" id="smartBundlingAtcSuccess-${utilityNeed.mainSku}">
                <img src="[@wsgc.docurl url='images/shop/loading.gif'/]"/>
                <p>Adding to cart....</p>
            </div>
            [@smartBundlingOneLine utilityNeed=utilityNeed /]
            <div class="smart-bundling-items" id="smartBundlingItems-${utilityNeed.mainSku}">
                [#local utilityNeedObjectJson = model.hashOrListToJson(utilityNeed) /]
                [#local utilitySkus = utilityNeed.data.members]
                [#list utilitySkus as utilitySku]
                    [#local utilitySkuJson = model.hashOrListToJson(utilitySku) /]
                    [#if utilitySku.copy?? && !shouldHideUtilitySkuCopy()]
                        [#assign flexClass = "smart-bundling-item-display-flex" /]
                    [#else]
                        [#assign flexClass = "" /]
                    [/#if ]
                    <div class="smart-bundling-item ${flexClass}" id="smartBundlingItem-${utilityNeed.mainSku}-${utilitySku.sku}">
                        [#if utilitySku.copy?? && utilityNeed.mainSku?? && !shouldHideUtilitySkuCopy()]
                            [@smartBundlingUtilityCopy mainSku=utilityNeed.mainSku memberCopy=utilitySku.copy/]
                        [/#if]
                        [@wsgc.dojoaddonloadNested]
                            wsgc.js.SmartBundlingCartUtils.getSmartBundlingContentCart(${utilityNeedObjectJson}, ${utilitySkuJson}, ${utilitySku.sku}, ${utilityNeed.mainSku}, "${mainSkuGroupId}")
                        [/@wsgc.dojoaddonloadNested]
                    </div>
                [/#list]
            </div>
        </div>
    [/#list]
[/#macro]